@@ -745,6 +745,21 @@ class _CIMutableMultiDictTests(_Root):
 
         self.assertEqual([('Key2', 'val3'), ('Key', 'val')], list(d.items()))
 
+    def test_update_istr(self):
+        d = self.make_dict()
+        d.add(istr('KEY'), 'val1')
+        d.add('key', 'val2')
+        d.add('key2', 'val3')
+
+        d.update({istr('key'): 'val'})
+
+        self.assertEqual([('Key2', 'val3'), ('Key', 'val')], list(d.items()))
+
+    def test_copy_istr(self):
+        d = self.make_dict({istr('Foo'): 'bar'})
+        d2 = d.copy()
+        self.assertEqual(d, d2)
+
 
 class TestPyMultiDictProxy(_TestProxy, unittest.TestCase):
 
@@ -868,6 +883,20 @@ class TypesMixin:
         p = self.proxy(d)
         self.assertEqual(p, d)
 
+    def test_create_multidict_proxy_from_multidict_proxy_from_mdict(self):
+        d = self.mdict(key='val')
+        p = self.proxy(d)
+        self.assertEqual(p, d)
+        p2 = self.proxy(p)
+        self.assertEqual(p2, p)
+
+    def test_create_cimultidict_proxy_from_cimultidict_proxy_from_ci(self):
+        d = self.cimdict(key='val')
+        p = self.ciproxy(d)
+        self.assertEqual(p, d)
+        p2 = self.ciproxy(p)
+        self.assertEqual(p2, p)
+
     def test_create_cimultidict_proxy_from_nonmultidict(self):
         with self.assertRaises(TypeError):
             self.ciproxy({})
